@@ -18,7 +18,7 @@
 #***	External imports.
 #**********************************************************************************************************************
 import inspect
-import logging
+import itertools
 import os
 import sys
 import re
@@ -27,15 +27,14 @@ import re
 #***	Internal imports.
 #**********************************************************************************************************************
 import foundations.common
-import foundations.core as core
 import foundations.dataStructures
 import foundations.exceptions
-import foundations.strings as strings
+import foundations.strings
+import foundations.verbose
 import foundations.walkers
 import manager.exceptions
 from foundations.parsers import SectionsFileParser
 from manager.component import Component
-from manager.globals.constants import Constants
 from manager.qobjectComponent import QObjectComponent
 from manager.qwidgetComponent import QWidgetComponentFactory
 
@@ -51,7 +50,7 @@ __status__ = "Production"
 
 __all__ = ["LOGGER", "Components", "Profile", "Manager"]
 
-LOGGER = logging.getLogger(Constants.logger)
+LOGGER = foundations.verbose.installLogger()
 
 #**********************************************************************************************************************
 #***	Module classes and definitions.
@@ -61,7 +60,6 @@ class Components(foundations.dataStructures.Structure):
 	This class represents a storage object for :class:`Manager` class Components.
 	"""
 
-	@core.executionTrace
 	def __init__(self, **kwargs):
 		"""
 		This method initializes the class.
@@ -78,7 +76,6 @@ class Profile(object):
 	This class is used by the :class:`Manager` class to store Components informations and objects.
 	"""
 
-	@core.executionTrace
 	def __init__(self, name=None, file=None):
 		"""
 		This method initializes the class.
@@ -97,7 +94,7 @@ class Profile(object):
 
 		self.__directory = None
 		self.__attribute = None
-		self.__rank = None
+		self.__require = None
 		self.__module = None
 		self.__interface = None
 		self.__category = None
@@ -124,7 +121,7 @@ class Profile(object):
 		return self.__name
 
 	@name.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def name(self, value):
 		"""
 		This method is the setter method for **self.__name** attribute.
@@ -138,7 +135,7 @@ class Profile(object):
 		self.__name = value
 
 	@name.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def name(self):
 		"""
 		This method is the deleter method for **self.__name** attribute.
@@ -158,7 +155,7 @@ class Profile(object):
 		return self.__file
 
 	@file.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def file(self, value):
 		"""
 		This method is the setter method for **self.__file** attribute.
@@ -171,7 +168,7 @@ class Profile(object):
 		self.__file = value
 
 	@file.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def file(self):
 		"""
 		This method is the deleter method for **self.__file** attribute.
@@ -191,7 +188,7 @@ class Profile(object):
 		return self.__directory
 
 	@directory.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def directory(self, value):
 		"""
 		This method is the setter method for **self.__directory** attribute.
@@ -206,7 +203,7 @@ class Profile(object):
 		self.__directory = value
 
 	@directory.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def directory(self):
 		"""
 		This method is the deleter method for **self.__directory** attribute.
@@ -226,7 +223,7 @@ class Profile(object):
 		return self.__attribute
 
 	@attribute.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def attribute(self, value):
 		"""
 		This method is the setter method for **self.__attribute** attribute.
@@ -240,7 +237,7 @@ class Profile(object):
 		self.__attribute = value
 
 	@attribute.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def attribute(self):
 		"""
 		This method is the deleter method for **self.__attribute** attribute.
@@ -250,38 +247,38 @@ class Profile(object):
 		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "attribute"))
 
 	@property
-	def rank(self):
+	def require(self):
 		"""
-		This method is the property for **self.__rank** attribute.
+		This method is the property for **self.__require** attribute.
 
-		:return: self.__rank. ( String )
+		:return: self.__require. ( Tuple / List )
 		"""
 
-		return self.__rank
+		return self.__require
 
-	@rank.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
-	def rank(self, value):
+	@require.setter
+	@foundations.exceptions.handleExceptions(AssertionError)
+	def require(self, value):
 		"""
-		This method is the setter method for **self.__rank** attribute.
+		This method is the setter method for **self.__require** attribute.
 
-		:param value: Attribute value. ( String )
+		:param value: Attribute value. ( Tuple / List )
 		"""
 
 		if value is not None:
-			assert type(value) in (str, unicode), "'{0}' attribute: '{1}' type is not 'str' or 'unicode'!".format(
-			"rank", value)
-		self.__rank = value
+			assert type(value) in (tuple, list), "'{0}' attribute: '{1}' type is not 'tuple' or 'list'!".format(
+			"require", value)
+		self.__require = value
 
-	@rank.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
-	def rank(self):
+	@require.deleter
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
+	def require(self):
 		"""
-		This method is the deleter method for **self.__rank** attribute.
+		This method is the deleter method for **self.__require** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
-		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "rank"))
+		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "require"))
 
 	@property
 	def module(self):
@@ -294,7 +291,7 @@ class Profile(object):
 		return self.__module
 
 	@module.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def module(self, value):
 		"""
 		This method is the setter method for **self.__module** attribute.
@@ -307,7 +304,7 @@ class Profile(object):
 		self.__module = value
 
 	@module.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def module(self):
 		"""
 		This method is the deleter method for **self.__module** attribute.
@@ -337,7 +334,7 @@ class Profile(object):
 		self.__interface = value
 
 	@interface.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def interface(self):
 		"""
 		This method is the deleter method for **self.__interface** attribute.
@@ -357,7 +354,7 @@ class Profile(object):
 		return self.__category
 
 	@category.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def category(self, value):
 		"""
 		This method is the setter method for **self.__category** attribute.
@@ -371,7 +368,7 @@ class Profile(object):
 		self.__category = value
 
 	@category.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def category(self):
 		"""
 		This method is the deleter method for **self.__category** attribute.
@@ -391,7 +388,7 @@ class Profile(object):
 		return self.__title
 
 	@title.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def title(self, value):
 		"""
 		This method is the setter method for **self.__title** attribute.
@@ -405,7 +402,7 @@ class Profile(object):
 		self.__title = value
 
 	@title.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def title(self):
 		"""
 		This method is the deleter method for **self.__title** attribute.
@@ -425,7 +422,7 @@ class Profile(object):
 		return self.__package
 
 	@package.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def package(self, value):
 		"""
 		This method is the setter method for **self.__package** attribute.
@@ -439,7 +436,7 @@ class Profile(object):
 		self.__package = value
 
 	@package.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def package(self):
 		"""
 		This method is the deleter method for **self.__package** attribute.
@@ -459,7 +456,7 @@ class Profile(object):
 		return self.__version
 
 	@version.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def version(self, value):
 		"""
 		This method is the setter method for **self.__version** attribute.
@@ -473,7 +470,7 @@ class Profile(object):
 		self.__version = value
 
 	@version.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def version(self):
 		"""
 		This method is the deleter method for **self.__version** attribute.
@@ -493,7 +490,7 @@ class Profile(object):
 		return self.__author
 
 	@author.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def author(self, value):
 		"""
 		This method is the setter method for **self.__author** attribute.
@@ -507,7 +504,7 @@ class Profile(object):
 		self.__author = value
 
 	@author.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def author(self):
 		"""
 		This method is the deleter method for **self.__author** attribute.
@@ -527,7 +524,7 @@ class Profile(object):
 		return self.__email
 
 	@email.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def email(self, value):
 		"""
 		This method is the setter method for **self.__email** attribute.
@@ -541,7 +538,7 @@ class Profile(object):
 		self.__email = value
 
 	@email.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def email(self):
 		"""
 		This method is the deleter method for **self.__email** attribute.
@@ -561,7 +558,7 @@ class Profile(object):
 		return self.__url
 
 	@url.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def url(self, value):
 		"""
 		This method is the setter method for **self.__url** attribute.
@@ -575,7 +572,7 @@ class Profile(object):
 		self.__url = value
 
 	@url.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def url(self):
 		"""
 		This method is the deleter method for **self.__url** attribute.
@@ -595,7 +592,7 @@ class Profile(object):
 		return self.__description
 
 	@description.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def description(self, value):
 		"""
 		This method is the setter method for **self.__description** attribute.
@@ -609,7 +606,7 @@ class Profile(object):
 		self.__description = value
 
 	@description.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def description(self):
 		"""
 		This method is the deleter method for **self.__description** attribute.
@@ -621,8 +618,7 @@ class Profile(object):
 	#******************************************************************************************************************
 	#***	Class methods.
 	#******************************************************************************************************************
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.FileStructureParsingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.FileStructureParsingError)
 	def initializeProfile(self):
 		"""
 		This method gets initializes the Component Profile.
@@ -641,47 +637,36 @@ class Profile(object):
 			self.__class__.__name__, attribute, self.__file))
 
 			self.__directory = os.path.dirname(self.__file)
-			self.__name = sectionsFileParser.attributeExists("Name", "Component") and \
-			sectionsFileParser.getValue("Name", "Component") or None
-			if not self.__name:
+			self.__name = sectionsFileParser.getValue("Name", "Component", default=None)
+			if self.__name is None:
 				raise fileStructureParsingError("Name")
 
-			self.__title = sectionsFileParser.attributeExists("Title", "Component") and \
-			sectionsFileParser.getValue("Title", "Component") or None
-			if not self.__title:
+			self.__title = sectionsFileParser.getValue("Title", "Component", default=None)
+			if self.__title is None:
 				self.__title = self.__name
 
-			self.__package = sectionsFileParser.attributeExists("Module", "Component") and \
-			sectionsFileParser.getValue("Module", "Component") or None
-			if not self.__package:
+			self.__package = sectionsFileParser.getValue("Module", "Component", default=None)
+			if self.__package is None:
 				raise fileStructureParsingError("Module")
 
-			self.__attribute = sectionsFileParser.attributeExists("Object", "Component") and \
-			sectionsFileParser.getValue("Object", "Component") or None
-			if not self.__attribute:
+			self.__attribute = sectionsFileParser.getValue("Object", "Component", default=None)
+			if self.__attribute is None:
 				raise fileStructureParsingError("Object")
 
-			self.__rank = sectionsFileParser.attributeExists("Rank", "Component") and \
-			sectionsFileParser.getValue("Rank", "Component") or None
-			if not self.__rank:
-				raise fileStructureParsingError("Rank")
+			self.__require = sectionsFileParser.getValue("Require", "Component", default=None)
+			self.__require = list() if self.__require is None else self.__require.split("|")
 
-			self.__version = sectionsFileParser.attributeExists("Version", "Component") and \
-			sectionsFileParser.getValue("Version", "Component") or None
-			if not self.__version:
+			self.__version = sectionsFileParser.getValue("Version", "Component", default=None)
+			if self.__version is None:
 				raise fileStructureParsingError("Version")
 
-			self.__author = sectionsFileParser.attributeExists("Author", "Informations") and \
-			sectionsFileParser.getValue("Author", "Informations") or None
+			self.__author = sectionsFileParser.getValue("Author", "Informations", default=None)
 
-			self.__email = sectionsFileParser.attributeExists("Email", "Informations") and \
-			sectionsFileParser.getValue("Email", "Informations") or None
+			self.__email = sectionsFileParser.getValue("Email", "Informations", default=None)
 
-			self.__url = sectionsFileParser.attributeExists("Url", "Informations") and \
-			sectionsFileParser.getValue("Url", "Informations") or None
+			self.__url = sectionsFileParser.getValue("Url", "Informations", default=None)
 
-			self.__description = sectionsFileParser.attributeExists("Description", "Informations") and \
-			sectionsFileParser.getValue("Description", "Informations") or None
+			self.__description = sectionsFileParser.getValue("Description", "Informations", default=None)
 
 			return True
 		else:
@@ -698,7 +683,6 @@ class Manager(object):
 		 this Profile object contains the Component Interface and various description attributes. 
 	"""
 
-	@core.executionTrace
 	def __init__(self,
 				paths=None,
 				extension="rc",
@@ -748,7 +732,7 @@ class Manager(object):
 		return self.__paths
 
 	@paths.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def paths(self, value):
 		"""
 		This method is the setter method for **self.__paths** attribute.
@@ -766,7 +750,7 @@ class Manager(object):
 		self.__paths = value
 
 	@paths.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def paths(self):
 		"""
 		This method is the deleter method for **self.__paths** attribute.
@@ -786,7 +770,7 @@ class Manager(object):
 		return self.__extension
 
 	@extension.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def extension(self, value):
 		"""
 		This method is the setter method for **self.__extension** attribute.
@@ -800,7 +784,7 @@ class Manager(object):
 		self.__extension = value
 
 	@extension.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def extension(self):
 		"""
 		This method is the deleter method for **self.__extension** attribute.
@@ -820,7 +804,7 @@ class Manager(object):
 		return self.__categories
 
 	@categories.setter
-	@foundations.exceptions.exceptionsHandler(None, False, AssertionError)
+	@foundations.exceptions.handleExceptions(AssertionError)
 	def categories(self, value):
 		"""
 		This method is the setter method for **self.__categories** attribute.
@@ -836,7 +820,7 @@ class Manager(object):
 		self.__categories = value
 
 	@categories.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def categories(self):
 		"""
 		This method is the deleter method for **self.__categories** attribute.
@@ -856,7 +840,7 @@ class Manager(object):
 		return self.__components
 
 	@components.setter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def components(self, value):
 		"""
 		This method is the setter method for **self.__components** attribute.
@@ -868,7 +852,7 @@ class Manager(object):
 		"{0} | '{1}' attribute is read only!".format(self.__class__.__name__, "components"))
 
 	@components.deleter
-	@foundations.exceptions.exceptionsHandler(None, False, foundations.exceptions.ProgrammingError)
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def components(self):
 		"""
 		This method is the deleter method for **self.__components** attribute.
@@ -880,8 +864,6 @@ class Manager(object):
 	#******************************************************************************************************************
 	#***	Class methods.
 	#******************************************************************************************************************
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def __getitem__(self, component):
 		"""
 		This method reimplements the :meth:`object.__getitem__` method.
@@ -900,8 +882,6 @@ class Manager(object):
 
 		return self.__components.__getitem__(component).interface
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def __iter__(self):
 		"""
 		This method reimplements the :meth:`object.__iter__` method.
@@ -922,8 +902,6 @@ class Manager(object):
 
 		return self.__components.iteritems()
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def __contains__(self, component):
 		"""
 		This method reimplements the :meth:`object.__contains__` method.
@@ -944,8 +922,6 @@ class Manager(object):
 
 		return component in self.__components.keys()
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def __len__(self):
 		"""
 		This method reimplements the :meth:`object.__len__` method.
@@ -963,10 +939,7 @@ class Manager(object):
 
 		return len(self.__components.keys())
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None,
-											False,
-											manager.exceptions.ComponentModuleError,
+	@foundations.exceptions.handleExceptions(manager.exceptions.ComponentModuleError,
 											manager.exceptions.ComponentProfileError)
 	def registerComponent(self, path):
 		"""
@@ -984,7 +957,7 @@ class Manager(object):
 		:return: Method success. ( Boolean )
 		"""
 
-		component = strings.getSplitextBasename(path)
+		component = foundations.strings.getSplitextBasename(path)
 		LOGGER.debug("> Current Component: '{0}'.".format(component))
 		profile = Profile(file=path)
 		if profile.initializeProfile():
@@ -1000,8 +973,6 @@ class Manager(object):
 			raise manager.exceptions.ComponentProfileError(
 			"{0} | '{1}' is not a valid Component and has been rejected!".format(self.__class__.__name__, component))
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def unregisterComponent(self, component):
 		"""
 		This method unregisters given Component.
@@ -1028,8 +999,7 @@ class Manager(object):
 		del(self.__components[component])
 		return True
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, manager.exceptions.ComponentRegistrationError)
+	@foundations.exceptions.handleExceptions(manager.exceptions.ComponentRegistrationError)
 	def registerComponents(self):
 		"""
 		This method registers the Components.
@@ -1058,8 +1028,6 @@ class Manager(object):
 			"{0} | '{1}' Components failed to register!".format(self.__class__.__name__,
 																", ".join(unregisteredComponents)))
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def unregisterComponents(self):
 		"""
 		This method unregisters the Components.
@@ -1085,8 +1053,7 @@ class Manager(object):
 		self.__components.clear()
 		return True
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, ImportError, manager.exceptions.ComponentInterfaceError)
+	@foundations.exceptions.handleExceptions(manager.exceptions.ComponentInterfaceError)
 	def instantiateComponent(self, component, callback=None):
 		"""
 		This method instantiates given Component.
@@ -1110,8 +1077,8 @@ class Manager(object):
 
 		LOGGER.debug("> Current Component: '{0}'.".format(component))
 
-		if os.path.isfile(os.path.join(profile.directory, profile.package) + ".py") or os.path.isdir(os.path.join(profile.directory,
-																							profile.package)):
+		if os.path.isfile(os.path.join(profile.directory, profile.package) + ".py") or \
+		os.path.isdir(os.path.join(profile.directory, profile.package)):
 			path = profile.directory
 		elif os.path.basename(profile.directory) == profile.package:
 			path = os.path.join(profile.directory, "..")
@@ -1132,8 +1099,6 @@ class Manager(object):
 			raise manager.exceptions.ComponentInterfaceError(
 			"{0} | '{1}' Component has no Interface and has been rejected!".format(self.__class__.__name__, profile.name))
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def instantiateComponents(self, callback=None):
 		"""
 		This method instantiates the Components.
@@ -1161,8 +1126,6 @@ class Manager(object):
 			"{0} | '{1}' Components failed to instantiate!".format(self.__class__.__name__,
 																	", ".join(uninstantiatedComponents)))
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, ImportError)
 	def reloadComponent(self, component):
 		"""
 		This method reload given Component module.
@@ -1185,44 +1148,71 @@ class Manager(object):
 		:return: Reload success. ( Boolean )
 		"""
 
-		profile = self.__components[component]
-		module = __import__(profile.package)
-		reload(module)
-		object = profile.attribute in dir(module) and getattr(module, profile.attribute) or None
-		if object and inspect.isclass(object):
-			for type in self.__categories.itervalues():
-				if type.__name__ in (base.__name__ for base in object.__bases__):
-					instance = object(name=profile.name)
-					profile.module = module
-					profile.interface = instance
-					LOGGER.info("{0} | '{1}' Component has been reloaded!".format(self.__class__.__name__, profile.name))
-					return True
+		dependents = list(reversed(self.listDependents(component)))
+		dependents.append(component)
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
-	def listComponents(self):
+		for dependent in dependents:
+			profile = self.__components[dependent]
+			module = __import__(profile.package)
+			reload(module)
+			object = profile.attribute in dir(module) and getattr(module, profile.attribute) or None
+			if object and inspect.isclass(object):
+				for type in self.__categories.itervalues():
+					if type.__name__ in (base.__name__ for base in object.__bases__):
+						instance = object(name=profile.name)
+						profile.module = module
+						profile.interface = instance
+						LOGGER.info("{0} | '{1}' Component has been reloaded!".format(self.__class__.__name__, profile.name))
+		return True
+
+	def listComponents(self, dependencyOrder=True):
 		"""
-		This method lists the Components by ranking.
+		This method lists the Components by dependency resolving.
 
 		Usage::
 
 			>>> manager = Manager(("./manager/tests/testsManager/resources/components/core",))
 			>>> manager.registerComponents()
 			True
-			>>> manager.components["core.testsComponentA"].rank
-			'10'
-			>>> manager.components["core.testsComponentB"].rank
-			'20'
 			>>> manager.listComponents()
 			['core.testsComponentA', 'core.testsComponentB']
 
+		:param dependencyOrder: Components are returned by dependency order. ( Boolean )
 		"""
 
-		return [foundations.common.getFirstItem(component) for component in sorted(((component, profile.rank)
-		for component, profile in self), key=lambda x:(int(x[1])))]
+		if dependencyOrder:
+			return list(itertools.chain.from_iterable([sorted(list(batch)) for batch in
+			foundations.common.dependencyResolver(dict((key, value.require) for (key, value) in self))]))
+		else:
+			return [key for (key, value) in self]
+
+	def listDependents(self, component, dependents=None):
+		"""
+		This method lists given Component dependents Components.
+
+		Usage::
+
+			>>> manager = Manager(("./manager/tests/testsManager/resources/components/core",))
+			>>> manager.registerComponents()
+			True
+			>>> manager.listDependents("core.testsComponentA")
+			['core.testsComponentB']
+
+		:param component: Component to retrieve the dependents Components. ( String )
+		:param dependents: Component dependents Components. ( Set )
+		:return: Dependent Components. ( List )
+		"""
+
+		dependents = set() if dependents is None else dependents
+		for name, profile in self:
+			if not component in profile.require:
+				continue
+
+			dependents.add(name)
+			self.listDependents(name, dependents)
+
+		return sorted(list(dependents), key=(self.listComponents()).index)
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def filterComponents(self, pattern, category=None):
 		"""
 		This method filters the Components using given regex pattern.
@@ -1237,7 +1227,7 @@ class Manager(object):
 
 		:param pattern: Regex filtering pattern. ( String )
 		:param category: Category filter. ( String )
-		:return: Matching items. ( List )
+		:return: Matching Components. ( List )
 		"""
 
 		matchingItems = []
@@ -1250,8 +1240,6 @@ class Manager(object):
 				matchingItems.append(component)
 		return matchingItems
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def getProfile(self, component):
 		"""
 		This method gets given Component profile.
@@ -1272,8 +1260,6 @@ class Manager(object):
 		if components != []:
 			return self.__components[foundations.common.getFirstItem(components)]
 
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def getInterface(self, component):
 		"""
 		This method gets given Component interface.
@@ -1295,8 +1281,6 @@ class Manager(object):
 			return profile.interface
 
 	@staticmethod
-	@core.executionTrace
-	@foundations.exceptions.exceptionsHandler(None, False, Exception)
 	def getComponentAttributeName(component):
 		"""
 		This method gets given Component attribute name.
