@@ -17,10 +17,7 @@
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
-import importlib
-import logging
 import os
-import pyclbr
 import re
 import shutil
 import sys
@@ -33,11 +30,10 @@ else:
 #***	Internal imports.
 #**********************************************************************************************************************
 import foundations.common
-import foundations.core as core
-import foundations.strings as strings
+import foundations.strings
+import foundations.verbose
 import foundations.walkers
 from foundations.io import File
-from foundations.globals.constants import Constants
 
 sys.path.append(os.path.join(os.path.dirname(os.path.abspath(__file__)), "libraries"))
 import python.pyclbr as moduleBrowser
@@ -53,7 +49,6 @@ __email__ = "thomas.mansencal@gmail.com"
 __status__ = "Production"
 
 __all__ = ["LOGGER",
-		"LOGGING_CONSOLE_HANDLER",
 		"FILES_EXTENSION",
 		"TOCTREE_TEMPLATE_BEGIN",
 		"TOCTREE_TEMPLATE_END",
@@ -63,13 +58,7 @@ __all__ = ["LOGGER",
 		"CONTENT_SUBSTITUTIONS",
 		"getSphinxDocumentationApi"]
 
-LOGGER = logging.getLogger(Constants.logger)
-
-LOGGING_CONSOLE_HANDLER = logging.StreamHandler(sys.stdout)
-LOGGING_CONSOLE_HANDLER.setFormatter(core.LOGGING_DEFAULT_FORMATTER)
-LOGGER.addHandler(LOGGING_CONSOLE_HANDLER)
-
-core.setVerbosityLevel(3)
+LOGGER = foundations.verbose.installLogger()
 
 FILES_EXTENSION = ".rst"
 
@@ -95,6 +84,9 @@ DECORATORS_COMMENT_MESSAGE = "#***\tSphinx: Decorator commented for auto-documen
 CONTENT_SUBSTITUTIONS = {"This method initializes the class.\n" :
 						".. Sphinx: Statements updated for auto-documentation purpose.\n"}
 
+foundations.verbose.getLoggingConsoleHandler()
+foundations.verbose.setVerbosityLevel(3)
+
 #**********************************************************************************************************************
 #***	Module classes and definitions.
 #**********************************************************************************************************************
@@ -135,7 +127,7 @@ def getSphinxDocumentationApi(packages, cloneDirectory, outputDirectory, apiFile
 		filtersOut=EXCLUDED_PYTHON_MODULES))):
 			LOGGER.info("{0} | Python file: '{1}'".format(getSphinxDocumentationApi.__name__, file))
 			module = "{0}.{1}" .format((".".join(os.path.dirname(file).replace(sourceDirectory, "").split("/"))),
-												strings.getSplitextBasename(file)).strip(".")
+												foundations.strings.getSplitextBasename(file)).strip(".")
 			LOGGER.info("{0} | Module name: '{1}'".format(getSphinxDocumentationApi.__name__, module))
 			directory = os.path.dirname(os.path.join(cloneDirectory, module.replace(".", "/")))
 			if not foundations.common.pathExists(directory):
@@ -144,14 +136,12 @@ def getSphinxDocumentationApi(packages, cloneDirectory, outputDirectory, apiFile
 			shutil.copyfile(file, source)
 
 			sourceFile = File(source)
-			sourceFile.read()
-			trimStartIndex = trimEndIndex = None
+			sourceFile.cache()
+			trimFromIndex = trimEndIndex = None
 			inMultilineString = inDecorator = False
 			for i, line in enumerate(sourceFile.content):
 				if re.search(r"__name__ +\=\= +\"__main__\"", line):
-					trimStartIndex = i
-				if trimStartIndex and re.search(r"^\s*$", line):
-					trimEndIndex = i
+					trimFromIndex = i
 				for pattern, value in CONTENT_SUBSTITUTIONS.iteritems():
 					if re.search(pattern, line):
 						sourceFile.content[i] = re.sub(pattern, value, line)
@@ -164,11 +154,11 @@ def getSphinxDocumentationApi(packages, cloneDirectory, outputDirectory, apiFile
 					continue
 
 				if re.search(r"^@\w+", strippedLine) and \
-					not re.search(r"@property", strippedLine) and \
-					not re.search(r"^@\w+\.setter", strippedLine) and \
-					not re.search(r"^@\w+\.deleter", strippedLine):
-						inDecorator = True
-						indent = re.search(r"^([ \t]*)", line)
+				not re.search(r"@property", strippedLine) and \
+				not re.search(r"^@\w+\.setter", strippedLine) and \
+				not re.search(r"^@\w+\.deleter", strippedLine):
+					inDecorator = True
+					indent = re.search(r"^([ \t]*)", line)
 
 				if re.search(r"^[ \t]*def \w+", sourceFile.content[i]) or \
 					re.search(r"^[ \t]*class \w+", sourceFile.content[i]):
@@ -179,11 +169,10 @@ def getSphinxDocumentationApi(packages, cloneDirectory, outputDirectory, apiFile
 
 				sourceFile.content[i] = "{0}{1} {2}".format(indent.groups()[0], DECORATORS_COMMENT_MESSAGE, line)
 
-			if trimStartIndex and trimEndIndex:
+			if trimFromIndex:
 				LOGGER.info("{0} | Trimming '__main__' statements!".format(getSphinxDocumentationApi.__name__))
-				content = [sourceFile.content[i] for i in range(trimStartIndex)]
-				content.append("\n{0}\n".format(STATEMENTS_UPDATE_MESSAGGE))
-				content.extend([sourceFile.content[i] for i in range(trimEndIndex, len(sourceFile.content))])
+				content = [sourceFile.content[i] for i in range(trimFromIndex)]
+				content.append("{0}\n".format(STATEMENTS_UPDATE_MESSAGGE))
 				sourceFile.content = content
 			sourceFile.write()
 
